@@ -627,9 +627,9 @@ def test_is_free_email_domain_empty_string():
 
 def test_is_free_email_domain_empty_series():
     is_free_email_domain = IsFreeEmailDomain()
-    array = pd.Series([])
+    array = pd.Series([], dtype="category")
     answers = pd.Series(is_free_email_domain(array))
-    correct_answers = pd.Series([])
+    correct_answers = pd.Series([], dtype="category")
     pd.testing.assert_series_equal(answers, correct_answers)
 
 
@@ -711,9 +711,9 @@ def test_email_address_to_domain_empty_string():
 
 def test_email_address_to_domain_empty_series():
     email_address_to_domain = EmailAddressToDomain()
-    array = pd.Series([])
+    array = pd.Series([], dtype="category")
     answers = pd.Series(email_address_to_domain(array))
-    correct_answers = pd.Series([])
+    correct_answers = pd.Series([], dtype="category")
     pd.testing.assert_series_equal(answers, correct_answers)
 
 
@@ -885,7 +885,7 @@ def test_date_to_time_zone_datetime64():
             datetime(2010, 1, 10),
             datetime(2020, 1, 1),
         ],
-    ).astype("datetime64")
+    ).astype("datetime64[ns]")
     x = x.dt.tz_localize("America/Los_Angeles")
     answer = pd.Series(["America/Los_Angeles"] * 3)
     pd.testing.assert_series_equal(primitive_func(x), answer)
